@@ -510,6 +510,9 @@ SERVICE_VERSIONS = {
     "smh": [
         "2021-07-12"
     ],
+    "smop": [
+        "2020-12-03"
+    ],
     "smpn": [
         "2019-08-22"
     ],
